Unit NT4api;
{ ========================================================================== }
{ =   Lynx Tecnologia Eletrnica Ltda.                                     = }
{ =   Projeto:   Windows NT4.0 Drivers - CAD12/32       Data: 12/ago/1999  = }
{ =   Programa:  Teste do driver da CAD12/32 para Windows NT4.0            = }
{ =   Mdulo:    NT4api                                                    = }
{ =   Autor:     Lauro                                                     = }
{ =   Descrio: Acesso s primitivas da DLL NT4_1232                      = }
{ =   Verso:    1.0                                                       = }
{ ========================================================================== }
{$ALIGN OFF}  { Desliga opo de alinhamento da memria }

{-------------------------  Descrio da Interface  -------------------------}
Interface
  Uses Windows;

{ ===================================================== }
{ =              Declarao de constantes             = }
{ ===================================================== }

  Const {---------------------------------- ieXXXX: Interrupt error status --}
    ieNoError        = 0;   { No error }
    ieIntOverrun     = 1;   { Interrupt overrun }
    ieAD_Error       = 2;   { A/D error }
    ieBufOverrun     = 3;   { Buffer list overrun }
    ieDriver         = 100; { Erro de acesso ao driver }
    ieAcqStop        = 101; { Aquisio no est ativa }
    ieBufSize        = 102; { Dimenso errada do buffer }

  Const {------------------ seXXXX: Cdigo de erro da NT4_StartAcquisition --}
    seNoError        = 0;   { No error }
    seNoSignal       = 1;   { Nenhum sinal habilitado }


{ ===================================================== }
{ =     Declarao de tipos e variveis pblicas      = }
{ ===================================================== }

  Type {--------------------------- Parmetro de entrada da NT4_DriverInfo --}
    TpAiRange = array [0..15] of single;
    TpDriverInfo = record
      VersionHigh : byte;	{ Driver version: high part }
      VersionLow  : byte;   	{ Driver version: low part }
      CAD_IoBase  : longint;    { CAD12/32 base port address (I/O space) }
      CAD_IRQ     : longint;    { CAD12/32 interrupt }
      CAD_DMA     : longint;    { not used }
      TmrClock    : single;     { Timer clock (Hz) }
      nAiChannels : smallint;   { Number of A/D channels }
      nAiRange    : smallint;   { Number of A/D input range }
                                { A/D input range (volts) }
      AiRange     : TpAiRange;
      nAoChannels : smallint;   { Number of D/A channels (not used) }
      nDiPorts    : smallint;   { Number of digital input ports }
      nBitsDI     : smallint;   { Number of bits per digital input port }
      nDoPorts    : smallint;   { Number of digital output ports }
      nBitsDO     : smallint;   { Number of bits per digital output port }
    end;

  Const
    cBufSize = 16384;     { Tamanho do buffer em bytes }

  Type {------------------------ Parmetro de sada da NT4_GetAcquiredData --}
    TpUserBuf = array [0..cBufSize] of smallint;
    TpAcquiredData = record
      ieStatus: dword;      { Status da aquisio }
      nSamples: dword;      { Nmero de amostras aquisitadas por canal }
      nSampGot: dword;      { Mmero de amostras transferidas por canal }
      iLast   : dword;      { last sample time order in the user buffer }
      UserBuf : TpUserBuf;
    end;


{ ===================================================== }
{ =          Declarao de variveis pblicas         = }
{ ===================================================== }

  Var
    DriverInfo: TpDriverInfo;  { Informaes do driver }


{ ========================================================================== }
{ =                     Primitivas do driver NT4_1232                      = }
{ ========================================================================== }

  {-- Primitivas de controle de acesso e iniciao --}
  Function  NT4_Open: dword; stdcall;
  Procedure NT4_Close; stdcall;
  Function  NT4_DriverInfo (Var DriverInfo: TpDriverInfo): boolean; stdcall;
  Function  NT4_GetVersion (Var VersionHigh, VersionLow: byte): boolean; stdcall;
  Function  NT4_GetAIO_Caps (Var TmrClock: single;
                             Var nAiChannels, nAoChannels, nAiRange: smallint;
                             Var AiRange: TpAiRange): boolean; stdcall;
  Function  NT4_GetDIO_Caps (Var nDiPorts, nBitsDI: smallint;
                             Var nDoPorts, nBitsDO: smallint): boolean; stdcall;
  {-- Primitivas da aquisio por interrupo --}
  Procedure NT4_Clear_CM; stdcall;
  Function  NT4_Insert_AI_CM (Channel, iRange: byte): dword; stdcall;
  Function  NT4_Insert_DI_CM (Group: byte): dword; stdcall;
  Function  NT4_AcquisitionSetup (SampleFreq: single; Var ErrorCode: dword): dword; stdcall;
  Procedure NT4_StartAcquisition; stdcall;
  Procedure NT4_StopAcquisition; stdcall;
  Function  NT4_GetAcquiredData (Var AcqData: TpAcquiredData): dword; stdcall;
  Function  NT4_GetAcquiredDataVB (Var ieStatus, nSamples, nSampGot, iLast: dword;
                                   Var UserBuf: TpUserBuf): dword; stdcall;
  {-- Primitivas de E/S analgica --}
  Function  NT4_SetAiRange (iRange: byte): dword; stdcall;
  Function  NT4_ReadAi (Channel: byte; Var Value: smallint): dword; stdcall;
  Function  NT4_WriteAo (Channel: byte; Value: smallint): dword; stdcall;
  {-- Primitivas de E/S digital --}
  Function  NT4_ReadDI (Group: byte; Var Value: word): dword; stdcall;
  Function  NT4_WriteDO (Group: byte; Value: word): dword; stdcall;


{--------------------------  Bloco de Implementao  ------------------------}
Implementation


{ ========================================================================== }
{ =              Primitivas de controle de acesso ao driver                = }
{ ========================================================================== }

{----------------------------------------- Abre o acesso ao drive NT4_1232 --}
Function NT4_Open; stdcall; external 'NT4_1232.DLL';

{--------------------------------------- Fecha o acesso ao driver NT4_1232 --}
Procedure NT4_Close; stdcall; external 'NT4_1232.DLL';

{--------------------------- Obtm informaes do driver (no usar com VB) --}
Function NT4_DriverInfo; stdcall; external 'NT4_1232.DLL';

{------------------------------ Obtm a verso do driver (para uso com VB) --}
Function  NT4_GetVersion; stdcall; external 'NT4_1232.DLL';

{-------------------- Obtm os recursos de E/S analgica (para uso com VB) --}
Function  NT4_GetAIO_Caps; stdcall; external 'NT4_1232.DLL';

{----------------------- Obtm os recursos de E/S digital (para uso com VB) --}
Function  NT4_GetDIO_Caps; stdcall; external 'NT4_1232.DLL';

{----------------------------------------------- Limpa a memria de canais --}
Procedure NT4_Clear_CM; stdcall; external 'NT4_1232.DLL';

{--------------------------------------- Insere canal na memria de canais --}
Function NT4_Insert_AI_CM; stdcall; external 'NT4_1232.DLL';

{----------------------------- Insere entrada digital na memria de canais --}
Function NT4_Insert_DI_CM; stdcall; external 'NT4_1232.DLL';

{--------------------------------- Preparao da aquisio por interrupo --}
Function NT4_AcquisitionSetup; stdcall; external 'NT4_1232.DLL';

{-------------------------------------- Inicia a aquisio por interrupo --}
Procedure NT4_StartAcquisition; stdcall; external 'NT4_1232.DLL';

{------------------------------------ Finaliza a aquisio por interrupo --}
Procedure NT4_StopAcquisition; stdcall; external 'NT4_1232.DLL';

{---------- Leitura das amostras aquisitadas pelo driver (no usar com VB) --}
Function NT4_GetAcquiredData; stdcall; external 'NT4_1232.DLL';

{---------- Leitura das amostras aquisitadas pelo driver (para uso com VB) --}
Function NT4_GetAcquiredDataVB; stdcall; external 'NT4_1232.DLL';

{---------------------------------------------- Programa ganho da CAD12/32 --}
Function NT4_SetAiRange; stdcall; external 'NT4_1232.DLL';

{---------------------------------------- Le entrada analgica da CAD12/32 --}
Function NT4_ReadAi; stdcall; external 'NT4_1232.DLL';

{---------------------------------- Escreve em sada analgica da CAD12/32 --}
Function NT4_WriteAo; stdcall; external 'NT4_1232.DLL';

{--------------------------------- Le entrada digital da CAD12/32: P0 e P1 --}
Function NT4_ReadDI; stdcall; external 'NT4_1232.DLL';

{--------------------------- Escreve em sada digital da CAD12/32: P0 e P1 --}
Function NT4_WriteDO; stdcall; external 'NT4_1232.DLL';


{ ===================================================== }
{ =            Rotina de iniciao do mdulo          = }
{ ===================================================== }

end.







